searchNodes=[{"ref":"EctoResource.html","title":"EctoResource","type":"module","doc":"This module represents the generic CRUD functionality that is boilerplate within Phoenix context files. It provides a DSL to easily generate the basic functions for a schema. This allows the context to focus on interesting, atypical implementations rather than the redundent, drifting crud functions."},{"ref":"EctoResource.html#all/3","title":"EctoResource.all/3","type":"function","doc":"Returns a list of all the records for a given Schema. Examples iex&gt; all(Repo, User) [ %User{ __meta__: #Ecto.Schema.Metadata&lt;:loaded, &quot;users&quot;&gt;, id: 1, inserted_at: ~N[2019-08-15 18:52:50], email: &quot;example@example.com&quot;, updated_at: ~N[2019-08-15 18:52:50] } ]"},{"ref":"EctoResource.html#change/2","title":"EctoResource.change/2","type":"function","doc":"Creates a changeset for a given Schema iex&gt; change(%User{email: &quot;user@example.com&quot;}, %{email: &quot;updated-email@example.com&quot;}) #Ecto.Changeset&lt; action: nil, changes: %{}, errors: [], data: #Engine.BusinessPartners.BusinessPartner&lt;&gt;, valid?: true &gt;"},{"ref":"EctoResource.html#create/3","title":"EctoResource.create/3","type":"function","doc":"Creates a new record with the given changeset Examples iex&gt; create(Repo, User, %{email: &quot;user@example.com&quot;}) {:ok, %User{ __meta__: #Ecto.Schema.Metadata&lt;:loaded, &quot;users&quot;&gt;, inserted_at: ~N[2019-08-17 00:41:41], email: &quot;example@example.com&quot;, updated_at: ~N[2019-08-17 00:41:41] }}"},{"ref":"EctoResource.html#create!/3","title":"EctoResource.create!/3","type":"function","doc":"Same as create/3 but returns the struct or raises if the changeset is invalid."},{"ref":"EctoResource.html#delete/2","title":"EctoResource.delete/2","type":"function","doc":"Deletes a given Schema struct Examples iex&gt; delete(Repo, %User{id: 1}) {:ok, %User{ __meta__: #Ecto.Schema.Metadata&lt;:deleted, &quot;users&quot;&gt;, id: 1, inserted_at: ~N[2019-08-17 00:41:41], email: &quot;example@example.com&quot;, updated_at: ~N[2019-08-17 00:41:41] }}"},{"ref":"EctoResource.html#delete!/2","title":"EctoResource.delete!/2","type":"function","doc":"Same as delete/2 but returns the struct or raises if the changeset is invalid."},{"ref":"EctoResource.html#get/4","title":"EctoResource.get/4","type":"function","doc":"Gets a Schema struct by the given id. Can also take options to alter the resulting query. Examples iex&gt; get(Repo, User, 1) %User{ __meta__: #Ecto.Schema.Metadata&lt;:loaded, &quot;users&quot;&gt;, id: 1, inserted_at: ~N[2019-08-15 18:52:50], email: &quot;example@example.com&quot;, updated_at: ~N[2019-08-15 18:52:50] }"},{"ref":"EctoResource.html#get!/4","title":"EctoResource.get!/4","type":"function","doc":"Same as get/4 but raises Ecto.NoResultsError if no record was found."},{"ref":"EctoResource.html#resource/2","title":"EctoResource.resource/2","type":"macro","doc":""},{"ref":"EctoResource.html#resource_descriptions/1","title":"EctoResource.resource_descriptions/1","type":"function","doc":""},{"ref":"EctoResource.html#underscore_module_name/1","title":"EctoResource.underscore_module_name/1","type":"function","doc":"Get an underscored module name for use in generating functions. Examples iex&gt; underscore_module_name(User) &quot;user&quot;"},{"ref":"EctoResource.html#update/4","title":"EctoResource.update/4","type":"function","doc":"Updates a given Schema with the given attributes Examples iex&gt; update(Repo, User, %User{id: 1}, %{email: &quot;updated@example.com&quot;}) {:ok, %User{ __meta__: #Ecto.Schema.Metadata&lt;:loaded, &quot;users&quot;&gt;, id: 1, inserted_at: ~N[2019-08-15 18:52:50], email: &quot;updated@example.com&quot;, updated_at: ~N[2019-08-17 01:16:01] }}"},{"ref":"EctoResource.html#update!/4","title":"EctoResource.update!/4","type":"function","doc":"Same as update/4 but returns the struct or raises if the changeset is invalid."},{"ref":"EctoResource.html#using_repo/2","title":"EctoResource.using_repo/2","type":"macro","doc":""},{"ref":"EctoResource.OptionParser.html","title":"EctoResource.OptionParser","type":"module","doc":""},{"ref":"EctoResource.OptionParser.html#parse/2","title":"EctoResource.OptionParser.parse/2","type":"function","doc":""},{"ref":"Mix.Tasks.EctoResource.Resources.html","title":"Mix.Tasks.EctoResource.Resources","type":"task","doc":"Task to list the resources defined by EctoResource within a context module. Examples $ mix ecto_resource.resources MyApp.MyContext Within the context Account, the following resource functions have been generated: User using the repo Repo: - Accounts.all_users/1 - Accounts.change_user/1 - Accounts.create_user/1 - Accounts.delete_user/1 - Accounts.get_user/2 - Accounts.update_user/2"},{"ref":"Mix.Tasks.EctoResource.Resources.html#run/1","title":"Mix.Tasks.EctoResource.Resources.run/1","type":"function","doc":"A task needs to implement run which receives a list of command line args. Callback implementation for Mix.Task.run/1."},{"ref":"readme.html","title":"EctoResource","type":"extras","doc":"EctoResource Eliminate boilerplate involved in defining basic CRUD functions in a Phoenix context or Elixir module. Turn this: defmodule MyApp.Accounts do @moduledoc &quot;&quot;&quot; The Accounts context. &quot;&quot;&quot; import Ecto.Query, warn: false alias MyApp.Repo alias MyApp.Accounts.User @doc &quot;&quot;&quot; Returns the list of users. ## Examples iex&gt; all_users() [%User{}, ...] &quot;&quot;&quot; def all_users do Repo.all(User) end @doc &quot;&quot;&quot; Gets a single user. ## Examples iex&gt; get_user(123) {:ok, %User{}} iex&gt; get_user(456) {:error, %Ecto.Changeset{}} &quot;&quot;&quot; def get_user(id), do: Repo.get(User, id) @doc &quot;&quot;&quot; Gets a single user. Raises [`Ecto.NoResultsError`](https://hexdocs.pm/ecto/3.1.7/Ecto.NoResultsError.html) if the User does not exist. ## Examples iex&gt; get_user!(123) %User{} iex&gt; get_user!(456) ** (Ecto.NoResultsError) &quot;&quot;&quot; def get_user!(id), do: Repo.get!(User, id) @doc &quot;&quot;&quot; Creates a user. ## Examples iex&gt; create_user(%{field: value}) {:ok, %User{}} iex&gt; create_user(%{field: bad_value}) {:error, %Ecto.Changeset{}} &quot;&quot;&quot; def create_user(attrs \\\\ %{}) do %User{} |&gt; User.changeset(attrs) |&gt; Repo.insert() end @doc &quot;&quot;&quot; Creates a user. Raises [`Postgrex.Error`](https://hexdocs.pm/postgrex/0.15.0/Postgrex.Error.html) if the insert fails. ## Examples iex&gt; create_user!(%{field: value}) {:ok, %User{}} iex&gt; create_user!(%{field: bad_value}) ** (Postgrex.Error) &quot;&quot;&quot; def create_user!(attrs \\\\ %{}) do %User{} |&gt; User.changeset(attrs) |&gt; Repo.insert!() end @doc &quot;&quot;&quot; Updates a user. ## Examples iex&gt; update_user(user, %{field: new_value}) {:ok, %User{}} iex&gt; update_user(user, %{field: bad_value}) {:error, %Ecto.Changeset{}} &quot;&quot;&quot; def update_user(%User{} = user, attrs) do user |&gt; User.changeset(attrs) |&gt; Repo.update() end @doc &quot;&quot;&quot; Updates a user. Raises [`Postgrex.Error`](https://hexdocs.pm/postgrex/0.15.0/Postgrex.Error.html) if the update fails. ## Examples iex&gt; update_user!(user, %{field: new_value}) {:ok, %User{}} iex&gt; update_user!(user, %{field: bad_value}) ** (Postgrex.Error) &quot;&quot;&quot; def update_user!(%User{} = user, attrs) do user |&gt; User.changeset(attrs) |&gt; Repo.update!() end @doc &quot;&quot;&quot; Deletes a User. ## Examples iex&gt; delete_user(user) {:ok, %User{}} iex&gt; delete_user(user) {:error, %Ecto.Changeset{}} &quot;&quot;&quot; def delete_user(%User{} = user) do Repo.delete(user) end @doc &quot;&quot;&quot; Deletes a User. Raises [`Postgrex.Error`](https://hexdocs.pm/postgrex/0.15.0/Postgrex.Error.html) if the delete fails. ## Examples iex&gt; delete_user!(user) {:ok, %User{}} iex&gt; delete_user!(user) ** (Postgrex.Error) &quot;&quot;&quot; def delete_user!(%User{} = user) do Repo.delete!(user) end @doc &quot;&quot;&quot; Returns an `%Ecto.Changeset{}` for tracking user changes. ## Examples iex&gt; change_user(user) %Ecto.Changeset{source: %User{}} &quot;&quot;&quot; def change_user(%User{} = user) do User.changeset(user, %{}) end end Into this: defmodule MyApp.Accounts do use EctoResource alias MyApp.Repo alias MyApp.Accounts.User using_repo(Repo) do resource(User) end end"},{"ref":"readme.html#installation","title":"EctoResource - Installation","type":"extras","doc":"If available in Hex, the package can be installed by adding ecto_resource to your list of dependencies in mix.exs: def deps do [ {:ecto_resource, &quot;~&gt; 0.1.0&quot;} ] end"},{"ref":"readme.html#basic-usage","title":"EctoResource - Basic Usage","type":"extras","doc":"All examples are using a &quot;context&quot; module Accounts and a schema of User. This can be substituted for your Phoenix context, or any other module and schema. defmodule Accounts do use EctoResource using_repo(Repo) do resource(User) end end This will generate the functions: def create_user(attributes) do EctoResource.create(Repo, User, attributes) end def create_user!(attributes) do EctoResource.create!(Repo, User, attributes) end def all_users(options) do EctoResource.all(Repo, User, options) end def get_user(id, options) do EctoResource.get(Repo, User, id, options) end def get_user!(id, options) do EctoResource.get!(Repo, User, id, options) end def change_user(struct_or_changeset) do EctoResource.change(User, struct_or_changeset) end def update_user(%User{id: 1}, changeset) do EctoResource.update(Repo, User, struct, changeset) end def update_user!(%User{id: 1}, changeset) do EctoResource.update!(Repo, User, struct, changeset) end def delete_user(struct_or_changeset) do EctoResource.delete(Repo, struct_or_changeset) end def delete_user!(struct_or_changeset) do EctoResource.delete!(Repo, struct_or_changeset) end There are also introspection functions to understand what is generated by the macro Accounts.__resource__(:resources) == [ {Repo, User, [ &quot;all_users/1&quot;, &quot;change_user/1&quot;, &quot;create_user/1&quot;, &quot;create_user!/1&quot;, &quot;delete_user/1&quot;, &quot;delete_user!/1&quot;, &quot;get_user/2&quot;, &quot;get_user!/2&quot;, &quot;update_user/2&quot;, &quot;update_user!/2&quot; ]} ]"},{"ref":"readme.html#advanced-usage","title":"EctoResource - Advanced usage","type":"extras","doc":"More granular control is available through options"},{"ref":"readme.html#read","title":"EctoResource - :read","type":"extras","doc":"defmodule Accounts do use EctoResource using_repo(Repo) do resource(User, :read) end end This will generate the functions: def all_users(options) do EctoResource.all(Repo, User, options) end def get_user(id, options) do EctoResource.get(Repo, User, id, options) end def get_user!(id, options) do EctoResource.get!(Repo, User, id, options) end There are also introspection functions to understand what is generated by the macro Accounts.__resource__(:resources) == [ {Repo, User, [ &quot;all_users/1&quot;, &quot;get_user/2&quot;, &quot;get_user!/2&quot; ]} ]"},{"ref":"readme.html#write","title":"EctoResource - :write","type":"extras","doc":"defmodule Accounts do use EctoResource using_repo(Repo) do resource(User, :write) end end This will generate the functions: def create_user(attributes) do EctoResource.create(Repo, User, attributes) end def create_user!(attributes) do EctoResource.create!(Repo, User, attributes) end def change_user(struct_or_changeset) do EctoResource.change(User, struct_or_changeset) end def update_user(%User{id: 1}, changeset) do EctoResource.update(Repo, User, struct, changeset) end def update_user!(%User{id: 1}, changeset) do EctoResource.update!(Repo, User, struct, changeset) end There are also introspection functions to understand what is generated by the macro Accounts.__resource__(:resources) == [ {Repo, User, [ &quot;change_user/1&quot;, &quot;create_user/1&quot;, &quot;create_user!/1&quot;, &quot;update_user/2&quot;, &quot;update_user!/2&quot; ]} ]"},{"ref":"readme.html#delete","title":"EctoResource - :delete","type":"extras","doc":"defmodule Accounts do use EctoResource using_repo(Repo) do resource(User, :delete) end end This will generate the functions: def delete_user(struct_or_changeset) do EctoResource.delete(Repo, struct_or_changeset) end def delete_user!(struct_or_changeset) do EctoResource.delete!(Repo, struct_or_changeset) end There are also introspection functions to understand what is generated by the macro Accounts.__resource__(:resources) == [ {Repo, User, [ &quot;delete_user/1&quot;, &quot;delete_user!/1&quot; ]} ]"},{"ref":"readme.html#only","title":"EctoResource - :only","type":"extras","doc":"defmodule Accounts do use EctoResource using_repo(Repo) do resource(User, only: [:change]) end This will generate the functions: def change_user(struct_or_changeset) do EctoResource.change(User, struct_or_changeset) end There are also introspection functions to understand what is generated by the macro Accounts.__resource__(:resources) == [ {Repo, User, [ &quot;change_user/1&quot; ]} ]"},{"ref":"readme.html#except","title":"EctoResource - :except","type":"extras","doc":"defmodule Accounts do use EctoResource using_repo(Repo) do resource(User, except: [:change]) end This will generate the functions: def create_user(attributes) do EctoResource.create(Repo, User, attributes) end def create_user!(attributes) do EctoResource.create!(Repo, User, attributes) end def all_users(options) do EctoResource.all(Repo, User, options) end def get_user(id, options) do EctoResource.get(Repo, User, id, options) end def get_user!(id, options) do EctoResource.get!(Repo, User, id, options) end def update_user(%User{id: 1}, changeset) do EctoResource.update(Repo, User, struct, changeset) end def update_user!(%User{id: 1}, changeset) do EctoResource.update!(Repo, User, struct, changeset) end def delete_user(struct_or_changeset) do EctoResource.delete(Repo, struct_or_changeset) end def delete_user!(struct_or_changeset) do EctoResource.delete!(Repo, struct_or_changeset) end There are also introspection functions to understand what is generated by the macro Accounts.__resource__(:resources) == [ {Repo, User, [ &quot;all_users/1&quot;, &quot;create_user/1&quot;, &quot;create_user!/1&quot;, &quot;delete_user/1&quot;, &quot;delete_user!/1&quot;, &quot;get_user/2&quot;, &quot;get_user!/2&quot;, &quot;update_user/2&quot;, &quot;update_user!/2&quot; ]} ] Documentation can be generated with ExDoc and published on HexDocs. Once published, the docs can be found at https://hexdocs.pm/ecto_resource."}]